/*
    This file is part of the syndication library.
    SPDX-FileCopyrightText: 2006 Frank Osterfeld <osterfeld@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef SYNDICATION_SYNDICATION_H
#define SYNDICATION_SYNDICATION_H

#include <syndication/abstractparser.h>
#include <syndication/category.h>
#include <syndication/constants.h>
#include <syndication/dataretriever.h>
#include <syndication/documentsource.h>
#include <syndication/documentvisitor.h>
#include <syndication/elementwrapper.h>
#include <syndication/enclosure.h>
#include <syndication/feed.h>
#include <syndication/global.h>
#include <syndication/image.h>
#include <syndication/item.h>
#include <syndication/loader.h>
#include <syndication/mapper.h>
#include <syndication/parsercollection.h>
#include <syndication/person.h>
#include <syndication/specificdocument.h>
#include <syndication/specificitem.h>
#include <syndication/specificitemvisitor.h>
#include <syndication/tools.h>

#endif // SYNDICATION_SYNDICATION_H
